pygeodesy.karney.GDict

Package pygeodesy :: Module karney :: Class GDict |
[frames] | no frames]

# Class GDict

    object --+
             |
          dict --+
                 |
       named.ADict --+
                     |
                    GDict

Known Subclasses:
  - geodesicx.gx._PDict

A `dict` with both `key` and `attribute` access to the `dict` items.

Results of all `geodesic` and `rhumb` methods (with capitalized named) are returned as GDict instances, see for example GeodesicExact and RhumbAux.

Instance Methods
toDirect9Tuple(self, dflt=nan) Convert this GDict result to a 9-tuple, like Karney's method `geographiclib.geodesic.Geodesic._GenDirect`. |
toGeod3Solve8Tuple(self, dflt=nan) Convert this GDict result to an 8-Tuple, compatible with Karney's Geod3Solve result. |
toGeodSolve12Tuple(self, dflt=nan) Convert this GDict result to a 12-Tuple, compatible with Karney's GeodSolve result. |
toInverse10Tuple(self, dflt=nan) Convert this GDict result to a 10-tuple, like Karney's method `geographiclib.geodesic.Geodesic._GenInverse`. |
toRhumb7Tuple(self, dflt=nan) DEPRECATED on 23.12.07, use method `toRhumb8Tuple`. |
toRhumb8Tuple(self, dflt=nan) Convert this GDict result to a 8-tuple. |
toRhumbSolve7Tuple(self, dflt=nan) Convert this GDict result to a 8-tuple. |
Inherited from `named.ADict`: `__getattr__`, `__repr__`, `__setattr__`, `__str__`, `set_`, `toRepr`, `toStr` Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
Inherited from `named.ADict`: `iteration`, `typename` Inherited from `object`: `__class__`

Method Details

### toDirect9Tuple (self, dflt=nan) |
Convert this GDict result to a 9-tuple, like Karney's method `geographiclib.geodesic.Geodesic._GenDirect`. Arguments: `dflt` - Default value for missing items (`any`). Returns: Direct9Tuple`(a12, lat2, lon2, azi2, s12, m12, M12, M21, S12)`

### toGeod3Solve8Tuple (self, dflt=nan) |
Convert this GDict result to an 8-Tuple, compatible with Karney's Geod3Solve result. Arguments: `dflt` - Default value for missing items (`any`). Returns: Geod3Solve8Tuple`(bet1, omg1, alp1, bet2, omg2, alp2, s12, a12)`.

### toGeodSolve12Tuple (self, dflt=nan) |
Convert this GDict result to a 12-Tuple, compatible with Karney's GeodSolve result. Arguments: `dflt` - Default value for missing items (`any`). Returns: GeodSolve12Tuple`(lat1, lon1, azi1, lat2, lon2, azi2, s12, a12, m12, M12, M21, S12)`.

### toInverse10Tuple (self, dflt=nan) |
Convert this GDict result to a 10-tuple, like Karney's method `geographiclib.geodesic.Geodesic._GenInverse`. Arguments: `dflt` - Default value for missing items (`any`). Returns: Inverse10Tuple`(a12, s12, salp1, calp1, salp2, calp2, m12, M12, M21, S12)`.

### toRhumb7Tuple (self, dflt=nan) |
DEPRECATED on 23.12.07, use method `toRhumb8Tuple`. Returns: A DEPRECATED Rhumb7Tuple. Decorators: `@deprecated_method`

### toRhumb8Tuple (self, dflt=nan) |
Convert this GDict result to a 8-tuple. Arguments: `dflt` - Default value for missing items (`any`). Returns: Rhumb8Tuple`(lat1, lon1, lat2, lon2, azi12, s12, S12, a12)`.

### toRhumbSolve7Tuple (self, dflt=nan) |
Convert this GDict result to a 8-tuple. Arguments: `dflt` - Default value for missing items (`any`). Returns: RhumbSolve7Tuple`(lat1, lon1, lat2, lon2, azi12, s12, S12)`.